@@ -2,7 +2,7 @@
 
 pub const LOG_BUF_CAPACITY: usize = 1024;
 
-pub const LOG_FIELDS: usize = 6;
+pub const LOG_FIELDS: usize = 7;
 
 #[repr(usize)]
 #[derive(Copy, Clone, Eq, PartialEq, Debug, Hash)]
@@ -37,8 +37,37 @@ pub enum RecordField {
     Module,
     File,
     Line,
+    NumArgs,
     Log,
 }
 
+#[repr(usize)]
+#[derive(Copy, Clone, Debug)]
+pub enum ArgType {
+    I8,
+    I16,
+    I32,
+    I64,
+    I128,
+    Isize,
+
+    U8,
+    U16,
+    U32,
+    U64,
+    U128,
+    Usize,
+
+    F32,
+    F64,
+
+    Str,
+}
+
 #[cfg(feature = "userspace")]
-unsafe impl aya::Pod for RecordField {}
+mod userspace {
+    use super::*;
+
+    unsafe impl aya::Pod for RecordField {}
+    unsafe impl aya::Pod for ArgType {}
+}
